Struct googapis::google::cloud::secretmanager::v1::ListSecretsRequest [−][src]
pub struct ListSecretsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
}Expand description
Request message for [SecretManagerService.ListSecrets][google.cloud.secretmanager.v1.SecretManagerService.ListSecrets].
Fields
parent: StringRequired. The resource name of the project associated with the
[Secrets][google.cloud.secretmanager.v1.Secret], in the format projects/*.
page_size: i32Optional. The maximum number of results to be returned in a single page. If set to 0, the server decides the number of results to return. If the number is greater than 25000, it is capped at 25000.
page_token: StringOptional. Pagination token, returned earlier via [ListSecretsResponse.next_page_token][google.cloud.secretmanager.v1.ListSecretsResponse.next_page_token].
filter: StringOptional. Filter string, adhering to the rules in List-operation filtering. List only secrets matching the filter. If filter is empty, all secrets are listed.